==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/StackedColumnSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedColumnSeriesDescription } from "./StackedColumnSeriesDescription";
/**
 * @hidden
 */
export let StackedColumnSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedColumnSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedColumnSeriesDescriptionMetadata.a == null) {
                StackedColumnSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedColumnSeriesDescriptionMetadata.c(StackedColumnSeriesDescriptionMetadata.a);
            }
            if (a.k(StackedColumnSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(StackedColumnSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            StackedColumnSeriesDescriptionMetadata.b(a);
            a.ad("StackedColumnSeries", () => new StackedColumnSeriesDescription());
            a.ac("StackedColumnSeries", StackedColumnSeriesDescriptionMetadata.a);
        }
    }
    StackedColumnSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedColumnSeriesDescriptionMetadata, 'StackedColumnSeriesDescriptionMetadata');
    StackedColumnSeriesDescriptionMetadata.a = null;
    return StackedColumnSeriesDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/StackedColumnSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedColumnSeriesDescription } from "./StackedColumnSeriesDescription";
/**
 * @hidden
 */
export let StackedColumnSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedColumnSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedColumnSeriesDescriptionMetadata.a == null) {
                StackedColumnSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedColumnSeriesDescriptionMetadata.c(StackedColumnSeriesDescriptionMetadata.a);
            }
            if (a.k(StackedColumnSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(StackedColumnSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            StackedColumnSeriesDescriptionMetadata.b(a);
            a.ae("StackedColumnSeries", () => new StackedColumnSeriesDescription());
            a.ad("StackedColumnSeries", StackedColumnSeriesDescriptionMetadata.a);
        }
    }
    StackedColumnSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedColumnSeriesDescriptionMetadata, 'StackedColumnSeriesDescriptionMetadata');
    StackedColumnSeriesDescriptionMetadata.a = null;
    return StackedColumnSeriesDescriptionMetadata;
})();
